package com.xinelu.manage.mapper.subscribemessagesendrecord;

import com.xinelu.manage.domain.subscribemessagesendrecord.SubscribeMessageSendRecord;
import com.xinelu.manage.dto.statistics.FollowUpRateDto;
import com.xinelu.manage.vo.statistics.MessageSendVo;
import com.xinelu.manage.vo.subscribemessagesendrecord.RecordNum;
import java.util.List;
import org.apache.ibatis.annotations.Param;

/**
 * 微信小程序订阅消息发送结果记录Mapper接口
 *
 * @author xinelu
 * @date 2024-03-19
 */
public interface SubscribeMessageSendRecordMapper {
    /**
     * 查询微信小程序订阅消息发送结果记录
     *
     * @param id 微信小程序订阅消息发送结果记录主键
     * @return 微信小程序订阅消息发送结果记录
     */
    SubscribeMessageSendRecord selectSubscribeMessageSendRecordById(Long id);

    /**
     * 查询微信小程序订阅消息发送结果记录列表
     *
     * @param subscribeMessageSendRecord 微信小程序订阅消息发送结果记录
     * @return 微信小程序订阅消息发送结果记录集合
     */
    List<SubscribeMessageSendRecord> selectSubscribeMessageSendRecordList(SubscribeMessageSendRecord subscribeMessageSendRecord);

    /**
     * 新增微信小程序订阅消息发送结果记录
     *
     * @param subscribeMessageSendRecord 微信小程序订阅消息发送结果记录
     * @return 结果
     */
    int insertSubscribeMessageSendRecord(SubscribeMessageSendRecord subscribeMessageSendRecord);

    /**
     * 修改微信小程序订阅消息发送结果记录
     *
     * @param subscribeMessageSendRecord 微信小程序订阅消息发送结果记录
     * @return 结果
     */
    int updateSubscribeMessageSendRecord(SubscribeMessageSendRecord subscribeMessageSendRecord);

    /**
     * 删除微信小程序订阅消息发送结果记录
     *
     * @param id 微信小程序订阅消息发送结果记录主键
     * @return 结果
     */
    int deleteSubscribeMessageSendRecordById(Long id);

    /**
     * 批量删除微信小程序订阅消息发送结果记录
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSubscribeMessageSendRecordByIds(Long[] ids);

    /**
     * 批量新增微信小程序订阅消息发送记录
     *
     * @param subscribeMessageSendRecordList 微信小程序订阅发送消息记录
     * @return int
     **/
    int insertSubscribeMessageSendRecordList(List<SubscribeMessageSendRecord> subscribeMessageSendRecordList);

    /**
     * 节点推送数量
     *
     * @param manageRouteNodeIds 节点id
     * @return RecordNum
     */
    List<RecordNum> selectRecordCountByManageRouteNodeIds(@Param("manageRouteNodeIds") List<Long> manageRouteNodeIds);

	List<MessageSendVo> getStatisticNum(FollowUpRateDto queryDto);
}
